RTPI - Oxfordshire

Oxontime Links

- Oxontime Home
- Search Options
- News / Status
- SMS Service
- About Oxontime
- Coverage
- Instructions / Help
- Terms of Use
- Text Only

Contact Us

- contact@oxontime.com
Oxontime RTI
Oxfordshire County Council
Speedwell House
Speedwell Street
Oxford OX1 1NE

# Search options

To find live departure information on bus services use the search options below and select your required bus stop.

﻿

Service Number | Operator | Destination
--- | --- | ---
1 | SOX | Oxford to Blackbird Leys
1 | SOX | Blackbird Leys to Oxford
10 | SOX | Oxford to JR Hospital
10 | SOX | JR Hospital to Oxford
101 | TT | Oxford City Centre to Watlington
101 | TT | Watlington to Oxford City Centre
105 | TT | Wallingford to Oxford City Centre
106 | TT | Oxford City Centre to Watlington
106 | TT | Watlington to Oxford City Centre
106A | TT | Watlington to Oxford City Centre
106C | TT | Oxford City Centre to Watlington
106C | TT | Watlington to Oxford City Centre
12 | SOX | Oxford to Greater Leys
12 | SOX | Greater Leys to Oxford
120 | *Voyager_PD_RAV(en-GB)* | Thame, Town Hall to Princes Risborough, Market Square
120 | *Voyager_PD_RAV(en-GB)* | Princes Risborough, Market Square to Thame, Town Hall
121 | *Voyager_PD_RAV(en-GB)* | Thame, Town Hall to Princes Risborough, Market Square
123 | *Voyager_PD_RAV(en-GB)* | Thame, Town Hall to Princes Risborough, Market Square
124 | *Voyager_PD_RAV(en-GB)* | Thame, Town Hall to Princes Risborough, Market Square
124 | *Voyager_PD_RAV(en-GB)* | Princes Risborough, Market Square to Thame, Town Hall
12C | SOX | Oxford to Greater Leys
12C | SOX | Greater Leys to Oxford
13 | OBC | Headington to Oxford City Centre
13 | OBC | Oxford City Centre to Headington
14 | SOX | Oxford to JR Hospital
14 | SOX | JR Hospital to Oxford
14A | SOX | Oxford to JR Hospital
14A | SOX | JR Hospital to Oxford
16 | SOX | Oxford to Minchery Farm
16 | SOX | Minchery Farm to Oxford
16A | SOX | Oxford to Minchery Farm
16A | SOX | Minchery Farm to Oxford
17 | SOX | Oxford to Cutteslowe
17 | SOX | Cutteslowe to Oxford
17A | SOX | Oxford to Cutteslowe
17A | SOX | Cutteslowe to Oxford
17C | SOX | Oxford to Cutteslowe
17C | SOX | Cutteslowe to Oxford
2 | SOX | Oxford to Kidlington
2 | OBC | Oxford City Centre to Kidlington
2 | SOX | Kidlington to Oxford
2 | OBC | Kidlington to Oxford City Centre
20 | SOX | Rose Hill to Cowley
20 | SOX | Cowley to Rose Hill
200 | *Voyager_PD_RAV(en-GB)* | Aylesbury, Bus Station Bay 11 to Oxford City Centre, Railway Station, Stop R4
200 | *Voyager_PD_RAV(en-GB)* | Oxford City Centre, Railway Station, Stop R4 to Aylesbury, Bus Station Bay 11
23 | OBC | Headington to Redbridge
23 | OBC | Redbridge to Headington
280 | *Voyager_PD_RAV(en-GB)* | Aylesbury, Bus Station Bay 11 to Oxford City Centre, Railway Station, Stop R4
280 | *Voyager_PD_RAV(en-GB)* | Oxford City Centre, Railway Station, Stop R4 to Aylesbury, Bus Station Bay 11
2A | SOX | Oxford to Kidlington
2A | OBC | Oxford City Centre to Kidlington
2A | SOX | Kidlington to Oxford
2A | OBC | Kidlington to Oxford City Centre
2B | SOX | Oxford to Kidlington
2B | OBC | Oxford City Centre to Kidlington
2B | SOX | Kidlington to Oxford
2B | OBC | Kidlington to Oxford City Centre
2C | SOX | Oxford to Kidlington
2C | OBC | Oxford City Centre to Kidlington
2C | SOX | Kidlington to Oxford
2C | OBC | Kidlington to Oxford City Centre
2D | SOX | Oxford to Kidlington
2D | OBC | Oxford City Centre to Kidlington
2D | SOX | Kidlington to Oxford
2D | OBC | Kidlington to Oxford City Centre
3 | SOX | Oxford to Rose Hill
3 | OBC | Oxford City Centre to Rose Hill
3 | SOX | Rose Hill to Oxford
3 | OBC | Rose Hill to Oxford City Centre
300 | OBC | Redbridge to Pear Tree
300 | OBC | Pear Tree to Redbridge
31 | SOX | Oxford to Wantage
31 | SOX | Wantage to Oxford
32 | TT | Abingdon Town Centre to Grove
32 | TT | Grove to Abingdon Town Centre
32A | TT | Oxford City Centre to Grove
32A | TT | Grove to Oxford City Centre
32B | TT | Abingdon Town Centre to Didcot
32B | TT | Didcot to Abingdon Town Centre
32C | TT | Abingdon Town Centre to Didcot
32C | TT | Didcot to Abingdon Town Centre
34 | SOX | Oxford to Wantage
34 | SOX | Wantage to Oxford
340 | *Voyager_PD_RAV(en-GB)* | High Wycombe, Bus Station, Gate A, Bay 3 to Stokenchurch, The King's Hotel
340 | *Voyager_PD_RAV(en-GB)* | Stokenchurch, The King's Hotel to High Wycombe, Bus Station, Gate A, Bay 3
35 | OBC | Oxford City Centre to Abingdon
35 | OBC | Abingdon to Oxford City Centre
36 | TT | Didcot to Wantage
36 | TT | Wantage to Didcot
3B | OBC | Rose Hill to Elms Rise
3B | OBC | Elms Rise to Rose Hill
4 | OBC | Wood Farm to Abingdon
4 | OBC | Abingdon to Wood Farm
40 | *Voyager_PD_RAV(en-GB)* | High Wycombe, Bus Station, Gate A, Bay 3 to Thame, Town Hall
40 | *Voyager_PD_RAV(en-GB)* | Thame, Town Hall to High Wycombe, Bus Station, Gate A, Bay 3
400 | OBC | Seacourt to Thornhill
400 | OBC | Thornhill to Seacourt
4A | OBC | Wood Farm to Dean Court
4A | OBC | Elms Rise to Wood Farm
4B | OBC | Wood Farm to Cumnor
4B | OBC | Cumnor to Wood Farm
4C | OBC | Wood Farm to Dean Court
4C | OBC | Dean Court to Wood Farm
5 | OBC | Oxford City Centre to Blackbird Leys
5 | OBC | Blackbird Leys to Oxford City Centre
500 | OBC | Oxford City Centre to Water Eaton
500 | OBC | Water Eaton to Oxford City Centre
6 | OBC | Oxford City Centre to Lower Wolvercote
6 | OBC | Lower Wolvercote to Oxford City Centre
6C | OBC | Lower Wolvercote to Oxford City Centre
8 | SOX | Oxford to Barton/Risinghurst
8 | OBC | Oxford City Centre to Barton
8 | SOX | Barton/Risinghurst to Oxford
8 | OBC | Barton to Oxford City Centre
800 | *Voyager_PD_RAV(en-GB)* | High Wycombe, Bus Station, Gate D, Bay 11 to Reading Town Centre, Friar Street, Stop FC
800 | *Voyager_PD_RAV(en-GB)* | Reading Town Centre, Friar Street, Stop FC to High Wycombe, Bus Station, Gate D, Bay 11
85 | SOX | Iffley to Cowley
85 | SOX | Cowley to Iffley
850 | *Voyager_PD_RAV(en-GB)* | High Wycombe, Bus Station, Gate E, Bay 13 to Reading Town Centre, Friar Street, Stop FC
850 | *Voyager_PD_RAV(en-GB)* | Reading Town Centre, Friar Street, Stop FC to High Wycombe, Bus Station, Gate E, Bay 13
86 | SOX | Lye Valley to Cowley
86 | SOX | Cowley to Lye Valley
89 | SOX | The Baldons to Cowley
89 | SOX | Cowley to The Baldons
9 | SOX | Oxford to Barton/Risinghurst
9 | OBC | Oxford City Centre to Risinghurst
9 | SOX | Barton/Risinghurst to Oxford
9 | OBC | Risinghurst to Oxford City Centre
94 | TT | Didcot to Milton Park
94 | TT | Milton Park to Didcot
95 | TT | Didcot to Didcot
95 | TT | Milton Park to Didcot
LGW | OBC | Oxford City Centre to Gatwick Airport
LHR | OBC | Oxford City Centre to Heathrow Airport
N1 | SOX | Oxford to Blackbird Leys
N1 | SOX | Blackbird Leys to Oxford
N10 | SOX | Oxford to JR Hospital
N10 | SOX | JR Hospital to Oxford
N2 | SOX | Oxford to Kidlington
N2 | SOX | Kidlington to Oxford
N3 | SOX | Oxford to Rose Hill
N3 | SOX | Rose Hill to Oxford
N30 | SOX | Oxford to Wantage
N30 | SOX | Wantage to Oxford
N31 | SOX | Oxford to Wantage
N31 | SOX | Wantage to Oxford
N32 | SOX | Oxford to Wantage
N32 | SOX | Wantage to Oxford
N8 | SOX | Oxford to Barton/Risinghurst
N8 | SOX | Barton/Risinghurst to Oxford
NS1 | SOX | Oxford to Carterton
NS1 | SOX | Carterton to Oxford
NS2 | SOX | Oxford to Carterton
NS2 | SOX | Carterton to Oxford
NS5 | SOX | Oxford to Bicester
NS5 | SOX | Bicester to Oxford
NU1 | OBC | Wheatley to Harcourt Hill
NU1 | OBC | Harcourt Hill to Wheatley
NU5 | OBC | Oxford City Centre to Headington
NU5 | OBC | Headington to Oxford City Centre
OXF | OBC | Gatwick Airport to Oxford City Centre
S1 | SOX | Oxford to Carterton
S1 | SOX | Carterton to Oxford
S2 | SOX | Oxford to Carterton
S2 | SOX | Carterton to Oxford
S3 | SOX | Oxford to Chipping Norton
S3 | SOX | Chipping Norton to Oxford
S4 | SOX | Oxford to Banbury
S4 | SOX | Banbury to Oxford
S5 | SOX | Oxford to Bicester
S5 | SOX | Bicester to Oxford
TUBE | SOX | Oxford to London
TUBE | SOX | London to Oxford
U1 | OBC | Wheatley to Harcourt Hill
U1 | OBC | Harcourt Hill to Wheatley
U4 | OBC | New Marston to Cowley
U4 | OBC | Cowley to Marston
U5 | OBC | Oxford City Centre to Wheatley
U5 | OBC | Wheatley to Oxford City Centre
U5X | OBC | The Plain to Wheatley
U5X | OBC | Wheatley to The Plain
X13 | OBC | Headington to Abingdon
X13 | OBC | Abingdon to Headington
X2 | OBC | Oxford City Centre to Didcot
X2 | OBC | Didcot to Oxford City Centre
X3 | OBC | Oxford City Centre to Abingdon
X3 | OBC | Abingdon to Oxford City Centre
X30 | SOX | Oxford to Wantage
X30 | SOX | Wantage to Oxford
X32 | TT | Oxford City Centre to Chilton
X32 | TT | Chilton to Oxford City Centre
X33 | TT | Oxford City Centre to Wantage
X36 | TT | Didcot to Wantage
X36 | TT | Wantage to Didcot
X39 | TT | Oxford City Centre to Reading Town Centre
X39 | TT | Reading Town Centre to Oxford City Centre
X40 | TT | Oxford City Centre to Reading Town Centre
X40 | TT | Reading Town Centre to Oxford City Centre
X90 | OBC | Oxford City Centre to Victoria
X90 | OBC | Victoria to Oxford City Centre